==> customsearch-0.5.0.tar.gz: DataGridField/Column.py <==
"""

    Basic columns for DataGridField

    Copyright 2006 Mikko Ohtamaa


"""

from __future__ import nested_scopes

__author__ = "Mikko Ohtamaa <snaapy@gmail.com>"
__docformat__ = 'reStructuredText'

# Python imports
import StringIO

# Zope imports
from AccessControl import ClassSecurityInfo
from AccessControl import getSecurityManager
from Globals import InitializeClass

from ZODB.POSException import ConflictError

# Plone imports
from Products.CMFCore.utils import getToolByName
from Products.CMFCore import CMFCorePermissions
from Products.Archetypes.public import *
from Products.Archetypes.Field import ObjectField, encode, decode, registerField

# Local imports
from Products.DataGridField.interfaces import IDataGridField

class Column:
    """ Stardard text edit column """

    security = ClassSecurityInfo()

    def __init__(self, label):
        """ Create a column
        @param label User visible name
        """
        self.label = label

    security.declarePublic('getLabel')
    def getLabel(self):
        """ User friendly name for the columnt """
        return self.label

    security.declarePublic('getMacro')
    def getMacro(self):
        """ Return macro used to render this column in view/edit """
        return "datagrid_text_cell"
    
    security.declarePublic('processCellData')
    def processCellData(self, form, value, context, field, columnId):
        """ Read cell values from raw form data
        
        Column processing in forms may need special preparations for data if
        widgets use other than <input value> for storing their
        values in fields.
        
        @param form Submitted form, contains HTML fields
        @param context Archetypes item instance for the submitted form
        @param field Assigned field for this widget
        @param columnId Column what we are operating
        
        @return new values which are constructed by processing data
        """
        return value

# Initializes class security
InitializeClass(Column)

==> customsearch-0.5.2.tar.gz: DataGridField/Column.py <==
"""

    Basic columns for DataGridField

    Copyright 2006 Mikko Ohtamaa


"""

from __future__ import nested_scopes

__author__ = "Mikko Ohtamaa <snaapy@gmail.com>"
__docformat__ = 'reStructuredText'

# Python imports
import StringIO

# Zope imports
from AccessControl import ClassSecurityInfo
from AccessControl import getSecurityManager
from Globals import InitializeClass

from ZODB.POSException import ConflictError

# Plone imports
from Products.CMFCore.utils import getToolByName
from Products.CMFCore import CMFCorePermissions
from Products.Archetypes.public import *
from Products.Archetypes.Field import ObjectField, encode, decode, registerField

# Local imports
from Products.DataGridField.interfaces import IDataGridField

class Column:
    """ Stardard text edit column """

    security = ClassSecurityInfo()

    def __init__(self, label, default=None):
        """ Create a column
        
            @param label User visible name
            @param default Default value for new rows
        """
        self.label = label
        self.default = default

    security.declarePublic('getLabel')
    def getLabel(self):
        """ User friendly name for the columnt """
        return self.label
    
    security.declarePublic('getDefault')
    def getDefault(self, context):
        """ Default value for new rows """
        return self.default

    security.declarePublic('getMacro')
    def getMacro(self):
        """ Return macro used to render this column in view/edit """
        return "datagrid_text_cell"
    
    security.declarePublic('processCellData')
    def processCellData(self, form, value, context, field, columnId):
        """ Read cell values from raw form data
        
        Column processing in forms may need special preparations for data if
        widgets use other than <input value> for storing their
        values in fields.
        
        @param form Submitted form, contains HTML fields
        @param context Archetypes item instance for the submitted form
        @param field Assigned field for this widget
        @param columnId Column what we are operating
        
        @return new values which are constructed by processing data
        """
        return value

# Initializes class security
InitializeClass(Column)
